Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(449)

Unified Diff: webkit/browser/fileapi/file_system_operation.h

Issue 21370003: Rename fileapi::LocalFileSystemOperation to FileSystemOperationImpl. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/browser/fileapi/async_file_util.h ('k') | webkit/browser/fileapi/file_system_operation_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/browser/fileapi/file_system_operation.h
diff --git a/webkit/browser/fileapi/file_system_operation.h b/webkit/browser/fileapi/file_system_operation.h
index a24c415a0f08026f08aa90633f6f157805de4662..f1adc191a7e38593c7bcdd34adb4b865dba8f9aa 100644
--- a/webkit/browser/fileapi/file_system_operation.h
+++ b/webkit/browser/fileapi/file_system_operation.h
@@ -31,7 +31,7 @@ namespace fileapi {
class FileSystemURL;
class FileWriterDelegate;
-class LocalFileSystemOperation;
+class FileSystemOperationImpl;
// The interface class for FileSystemOperation implementations.
//
@@ -230,10 +230,10 @@ class FileSystemOperation {
base::ProcessHandle peer_handle,
const OpenFileCallback& callback) = 0;
// For downcasting to FileSystemOperation.
// TODO(kinuko): this hack should go away once appropriate upload-stream
// handling based on element types is supported.
- virtual LocalFileSystemOperation* AsLocalFileSystemOperation() = 0;
+ virtual FileSystemOperationImpl* AsFileSystemOperationImpl() = 0;
// Creates a local snapshot file for a given |path| and returns the
// metadata and platform path of the snapshot file via |callback|.
« no previous file with comments | « webkit/browser/fileapi/async_file_util.h ('k') | webkit/browser/fileapi/file_system_operation_impl.h » ('j') | no next file with comments »
@@ -230,10 +230,10 @@ class FileSystemOperation {
base::ProcessHandle peer_handle,
const OpenFileCallback& callback) = 0;
- // For downcasting to FileSystemOperation.
+ // For downcasting to FileSystemOperationImpl.
// TODO(kinuko): this hack should go away once appropriate upload-stream
// handling based on element types is supported.

Powered by Google App Engine
This is Rietveld 408576698